@@ -73,7 +73,7 @@ def crop():
     cv2.waitKey(0)
 
 
-def get_iamge(devices,save_img_path,scale):
+def get_image(devices,save_img_path,scale):
     global Scale
     Scale=float(scale)
     screen_shot(devices,save_img_path)
@@ -136,7 +136,7 @@ def devices_connect(device_type,devices):
 
 # devices=devices_connect('android',None)
 # save_img_path='F:/'
-# get_iamge(devices,save_img_path,0.5)
+# get_image(devices,save_img_path,0.5)
 
 
 
